/**
 * Copyright (c) 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.api.command;

import java.io.PrintWriter;
import java.io.StringWriter;

import org.apache.commons.cli.HelpFormatter;

/**
 * Command utilities
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public final class CommandUtil {

    private CommandUtil() {
        // NOP: Utility class -> No constructor available
    }

    /**
     * Format the usage message of a command
     * 
     * @param command
     *            The command to print usage
     * 
     * @return The usage message of the command
     */
    public static final String formatCommandUsage(final Command command) {
        // use help formatter to provide well-formed description
        final HelpFormatter helpFormatter = new HelpFormatter();
        final StringWriter sw = new StringWriter();
        helpFormatter.printUsage(new PrintWriter(sw), HelpFormatter.DEFAULT_WIDTH,
                command.getName(), command.getOptions());
        return sw.toString();
    }

    /**
     * Format the option description of a command
     * 
     * @param command
     *            The command to print option description
     * 
     * @return The option description message of the command
     */
    public static final String formatCommandOptionsDescription(final Command command) {
        // use help formatter to provide well-formed description
        final HelpFormatter helpFormatter = new HelpFormatter();
        final StringWriter sw = new StringWriter();
        helpFormatter.printOptions(new PrintWriter(sw), HelpFormatter.DEFAULT_WIDTH,
                command.getOptions(), HelpFormatter.DEFAULT_LEFT_PAD,
                HelpFormatter.DEFAULT_DESC_PAD);
        return sw.toString();
    }

}
