/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.api.command;

import org.apache.commons.cli.CommandLine;
import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.ConnectionErrorException;
import org.ow2.petals.cli.api.connection.AuthenticatedConnectionParameters;
import org.ow2.petals.cli.api.connection.ConnectionParameters;
import org.ow2.petals.cli.api.connection.exception.InvalidConnectionParameterException;
import org.ow2.petals.cli.api.pref.PreferenceFileException;

/**
 * Dedicated interface for the command realizing the connection.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface ConnectionCommand extends Command {

    /**
     * Realize the connection using the provided connection parameter. If the authentication information are missing,
     * they are asked to the user or an error occurs according to the shell.
     * 
     * @param connectionParameters
     * @param isYesFlagEnabledAtCmdLevel
     *            <code>true</code> if the 'yes' flag is enabled at command level
     * @return The connection information including authentication part potentially asked to the user.
     * @throws ConnectionErrorException
     *             An error occurs establishing the connection
     * @throws CommandException
     *             An error occurs processing the command
     */
    public AuthenticatedConnectionParameters connect(final ConnectionParameters connectionParameters,
            final boolean isYesFlagEnabledAtCmdLevel) throws ConnectionErrorException, CommandException;
    
    /**
     * Parse the command line arguments to get connection information
     * 
     * @param cmd
     * @param useDefaultConnection
     *            Default values can be used
     * @return The connection parameters or <code>null</code> if no connection parameters are available
     * @throws CommandException
     * @throws PreferenceFileException
     * @throws InvalidConnectionParameterException
     */
    public ConnectionParameters parseConnectionParameters(final CommandLine cmd, final boolean useDefaultConnection)
            throws CommandException, PreferenceFileException, InvalidConnectionParameterException;

}
