/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.api.command;

import org.ow2.petals.cli.api.command.exception.CommandException;
import org.ow2.petals.cli.api.command.exception.DisconnectionErrorException;

/**
 * Dedicated interface for the command realizing a disconnection.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface DisconnectionCommand extends Command {

    /**
     * Realize a disconnection. If no connection was previously established, no error should occur.
     * 
     * @throws DisconnectionErrorException
     *             An error occurs disconnecting the connection
     * @throws CommandException
     *             An error occurs processing the command
     */
    public void disconnect() throws DisconnectionErrorException, CommandException;

    /**
     * @return <code>true</code> is a connection is established, <code>false</code> otherwise.
     * @throws DisconnectionErrorException
     *             An error occurs disconnecting the connection
     */
    public boolean isConnected() throws DisconnectionErrorException;

}
