/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.cli.api.connection;

import java.net.InetAddress;
import java.net.UnknownHostException;

import org.ow2.petals.cli.api.connection.exception.HostMissingException;
import org.ow2.petals.cli.api.connection.exception.InvalidPortException;

public class ConnectionParameters {
    
    private final InetAddress host;

    /**
     * To avoid to lookup the host IP address each time it is needed, we cache
     * it in this variable.
     */
    private final String strHost;

    private final int port;
 
    /**
     * 
     * @param host
     *            host name or IP address. Cannot be <code>null</code>.
     * @param port
     *            <code>0 > port >= 65535</code>
     * @throws UnknownHostException
     *             The host name can not be determined, or the IP address is invalid.
     * @throws HostMissingException
     *             The host is <code>null</code>
     * @throws InvalidPortException
     *             The host is invalid
     */
    public ConnectionParameters(final String host, final int port) throws UnknownHostException, HostMissingException,
            InvalidPortException {
        if (host == null) {
            throw new HostMissingException();
        }
        if ((port <= 0) || (port > 65535)) {
            throw new InvalidPortException();
        }
        
        this.host = InetAddress.getByName(host);
        this.strHost = this.host.getHostName();
        this.port = port;
    }

    public String getHost() {
        return this.strHost;
    }

    public int getPort() {
        return this.port;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;

        assert this.host != null : "host is not null, see constructor";

        result = prime * result + (this.host.hashCode());
        result = prime * result + this.port;
        return result;
    }

    @Override
    public boolean equals(final Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;

        assert this.host != null : "host is not null, see constructor";

        final ConnectionParameters other = (ConnectionParameters) obj;
        if (!this.host.equals(other.host))
            return false;
        if (this.port != other.port)
            return false;
        return true;
    }
}
